from Products.LDAPMultiPlugins.LDAPMultiPlugin import manage_addLDAPMultiPlugin
from Products.CMFCore.utils import getToolByName

from gsc.plone.ldapreader.config import gsc_web_ldap
from gsc.plone.ldapreader.config import gsc_ldap_to_plone_schema_mapping


def setupLDAP(context):
    "Configure LDAP User Folder"
    site = context.getSite()

    # *grumble* LDAPMultiPlugin doesn't allow us to configure the objectClasses
    props_without_oc = gsc_web_ldap.copy()
    del props_without_oc['object_classes']
    
    # Install the LDAP connection
    manage_addLDAPMultiPlugin(
        site.acl_users,
        id='gsc_web_ldap',
        **props_without_oc
    )
    
    # XXX avert your eyes!
    object_classes = [x.strip() for x in gsc_web_ldap['object_classes'].split(',')]
    site.acl_users.gsc_web_ldap.acl_users._delegate.u_classes = object_classes
    
    # Configure the LDAP to Plone schema mapping
    site.acl_users.gsc_web_ldap.acl_users.setSchemaConfig(
        gsc_ldap_to_plone_schema_mapping
    )
    
    # Indicate which LDAP functionality is desired
    site.acl_users.gsc_web_ldap.manage_activateInterfaces(
        [
          'IAuthenticationPlugin',
          'IGroupEnumerationPlugin',
          'IGroupsPlugin',
          'IPropertiesPlugin',
          'IRoleEnumerationPlugin',
          'IRolesPlugin',
          'IUserEnumerationPlugin',
        ]
    )

    # Remove LDAP-supplied properites from portal_memberdata
    memberdata = getToolByName(site, 'portal_memberdata')
    memberdata._delProperty('email')
    memberdata._delProperty('location')
    memberdata._delProperty('fullname')
