import unittest
from gsc.plone.ldapreader.tests.base import LDAPReaderTestCase

from Products.CMFCore.utils import getToolByName

#
# Run tests with:
# ./bin/instance test -s gsc.plone.ldapreader
#

# user data for testing
user1 = {
    'uid':'kteague',
    'username':'kteague',
    'email':'kteague@bcgsc.ca',
    'cn':'Kevin Teague',
    'location':'570 West 7th Ave',
}

user2 = {
    'uid':'rsantos',
}

default_mutable_properties = {
 'listed':False,
 'description':'',
 'language':'',
 'ext_editor':False,
 'wysiwyg_editor':'Kupu',
 'visible_ids':False,
}

class TestSetup(LDAPReaderTestCase):
    """
    Tests directly against the production LDAP install, using specific
    account records - not exactly the best thing perhaps, but it is a read-only
    package and the highly specific nature of this package ... *shrug*
    """
    
    def afterSetUp(self):
        self.acl_users = getToolByName(self.portal, 'acl_users')
        self.membership = getToolByName(self.portal, 'portal_membership')
        self.memberdata = getToolByName(self.portal, 'portal_memberdata')
        self.setup = getToolByName(self.portal, 'portal_setup')
        self.user1 = self.membership.getMemberById(user1['uid'])
        self.user2 = self.membership.getMemberById(user2['uid'])
    
    def test_user1_is_implemented_by_memberdata(self):
        self.assertEquals(
            str(self.user1.__provides__),
            '<implementedBy Products.PlonePAS.tools.memberdata.MemberData>'
        )

    def test_user2_is_implemented_by_memberdata(self):
        self.assertEquals(
            str(self.user1.__provides__),
            '<implementedBy Products.PlonePAS.tools.memberdata.MemberData>'
        )

    def test_user1_has_mapped_ldap_attributes(self):
        self.assertEquals(self.user1.getProperty('username'), user1['username'])
        self.assertEquals(self.user1.getProperty('email'), user1['email'])
        self.assertEquals(self.user1.getProperty('cn'), user1['cn'])
        self.assertEquals(self.user1.getProperty('location'), user1['location'])

    def test_user1_has_default_mutable_properties(self):
        for k,v in default_mutable_properties.items():
            self.assertEquals(getattr(self.user1,k),v)

    def test_ldap_is_read_only(self):
        self.assertEquals(self.user1.canWriteProperty('username'),False)
        self.assertEquals(self.user1.canWriteProperty('email'),False)
        self.assertEquals(self.user1.canWriteProperty('cn'),False)
        self.assertEquals(self.user1.canWriteProperty('location'),False)

def test_suite():
    suite = unittest.TestSuite()
    suite.addTest(unittest.makeSuite(TestSetup))
    return suite
